bing_geos = {
    'uk': 'http://www.bing.com/search?q={}&cc=GB&count={}',
    'us': 'http://www.bing.com/search?q={}&cc=US&count={}',
    'tr': 'http://www.bing.com/search?q={}&cc=TR&count={}',
    'tw': 'http://www.bing.com/search?q={}&cc=TW&count={}',
    'ch': 'http://www.bing.com/search?q={}&cc=CH&count={}',
    'se': 'http://www.bing.com/search?q={}&cc=SE&count={}',
    'es': 'http://www.bing.com/search?q={}&cc=ES&count={}',
    'za': 'http://www.bing.com/search?q={}&cc=ZA&count={}',
    'sa': 'http://www.bing.com/search?q={}&cc=SA&count={}',
    'ru': 'http://www.bing.com/search?q={}&cc=RU&count={}',
    'ph': 'http://www.bing.com/search?q={}&cc=PH&count={}',
    'pt': 'http://www.bing.com/search?q={}&cc=PT&count={}',
    'pl': 'http://www.bing.com/search?q={}&cc=PL&count={}',
    'cn': 'http://www.bing.com/search?q={}&cc=CN&count={}',
    'no': 'http://www.bing.com/search?q={}&cc=NO&count={}',
    'nz': 'http://www.bing.com/search?q={}&cc=NZ&count={}',
    'nl': 'http://www.bing.com/search?q={}&cc=NL&count={}',
    'mx': 'http://www.bing.com/search?q={}&cc=MX&count={}',
    'my': 'http://www.bing.com/search?q={}&cc=MY&count={}',
    'kr': 'http://www.bing.com/search?q={}&cc=KR&count={}',
    'j[': 'http://www.bing.com/search?q={}&cc=JP&count={}',
    'it': 'http://www.bing.com/search?q={}&cc=IT&count={}',
    'id': 'http://www.bing.com/search?q={}&cc=ID&count={}',
    'in': 'http://www.bing.com/search?q={}&cc=IN&count={}',
    'hk': 'http://www.bing.com/search?q={}&cc=HK&count={}',
    'de': 'http://www.bing.com/search?q={}&cc=DE&count={}',
    'fr': 'http://www.bing.com/search?q={}&cc=FR&count={}',
    'fi': 'http://www.bing.com/search?q={}&cc=FI&count={}',
    'dk': 'http://www.bing.com/search?q={}&cc=DK&count={}',
    'cl': 'http://www.bing.com/search?q={}&cc=CL&count={}',
    'ca': 'http://www.bing.com/search?q={}&cc=CA&count={}',
    'br': 'http://www.bing.com/search?q={}&cc=BR&count={}',
    'be': 'http://www.bing.com/search?q={}&cc=BE&count={}',
    'at': 'http://www.bing.com/search?q={}&cc=AT&count={}',
    'au': 'http://www.bing.com/search?q={}&cc=AU&count={}',
    'ar': 'http://www.bing.com/search?q={}&cc=AR&count={}'
}
