yandex_geos = {
    'GLOBAL': 'https://yandex.com/search/?text={}&lr={}&numdoc={}',
    'RU': 'https://yandex.ru/search/?text={}&lr={}&numdoc={}',
    'UA': 'https://yandex.ua/search/?text={}&lr={}&numdoc={}',
    'BY': 'https://yandex.by/search/?text={}&lr={}&numdoc={}',
    'KZ': 'https://yandex.kz/search/?text={}&lr={}&numdoc={}',
    'TR': 'https://yandex.tr/search/?text={}&lr={}&numdoc={}'
}